@@ -793,19 +793,42 @@ mod tests {
         solana_sdk::{hash::Hash, signature::Keypair, system_transaction},
         solana_storage_proto::convert::generated,
         solana_transaction_status::{
-            ConfirmedBlock, TransactionStatusMeta, TransactionWithStatusMeta,
+            ConfirmedBlock, ConfirmedBlockWithOptionalMetadata, TransactionStatusMeta,
+            TransactionWithMetadata,
         },
         std::convert::TryInto,
     };
 
+    fn confirmed_block_into_protobuf(confirmed_block: ConfirmedBlock) -> generated::ConfirmedBlock {
+        let ConfirmedBlock {
+            previous_blockhash,
+            blockhash,
+            parent_slot,
+            transactions,
+            rewards,
+            block_time,
+            block_height,
+        } = confirmed_block;
+
+        generated::ConfirmedBlock {
+            previous_blockhash,
+            blockhash,
+            parent_slot,
+            transactions: transactions.into_iter().map(Into::into).collect(),
+            rewards: rewards.into_iter().map(|r| r.into()).collect(),
+            block_time: block_time.map(|timestamp| generated::UnixTimestamp { timestamp }),
+            block_height: block_height.map(|block_height| generated::BlockHeight { block_height }),
+        }
+    }
+
     #[test]
     fn test_deserialize_protobuf_or_bincode_cell_data() {
         let from = Keypair::new();
         let recipient = solana_sdk::pubkey::new_rand();
         let transaction = system_transaction::transfer(&from, &recipient, 42, Hash::default());
-        let with_meta = TransactionWithStatusMeta {
+        let with_meta = TransactionWithMetadata {
             transaction,
-            meta: Some(TransactionStatusMeta {
+            meta: TransactionStatusMeta {
                 status: Ok(()),
                 fee: 1,
                 pre_balances: vec![43, 0, 1],
@@ -815,9 +838,9 @@ mod tests {
                 pre_token_balances: Some(vec![]),
                 post_token_balances: Some(vec![]),
                 rewards: Some(vec![]),
-            }),
+            },
         };
-        let block = ConfirmedBlock {
+        let expected_block = ConfirmedBlock {
             transactions: vec![with_meta],
             parent_slot: 1,
             blockhash: Hash::default().to_string(),
@@ -827,11 +850,14 @@ mod tests {
             block_height: Some(1),
         };
         let bincode_block = compress_best(
-            &bincode::serialize::<StoredConfirmedBlock>(&block.clone().into()).unwrap(),
+            &bincode::serialize::<StoredConfirmedBlock>(
+                &ConfirmedBlockWithOptionalMetadata::from(expected_block.clone()).into(),
+            )
+            .unwrap(),
         )
         .unwrap();
 
-        let protobuf_block = generated::ConfirmedBlock::from(block.clone());
+        let protobuf_block = confirmed_block_into_protobuf(expected_block.clone());
         let mut buf = Vec::with_capacity(protobuf_block.encoded_len());
         protobuf_block.encode(&mut buf).unwrap();
         let protobuf_block = compress_best(&buf).unwrap();
@@ -846,7 +872,10 @@ mod tests {
         )
         .unwrap();
         if let CellData::Protobuf(protobuf_block) = deserialized {
-            assert_eq!(block, protobuf_block.try_into().unwrap());
+            assert_eq!(
+                ConfirmedBlockWithOptionalMetadata::from(expected_block.clone()),
+                protobuf_block.try_into().unwrap(),
+            );
         } else {
             panic!("deserialization should produce CellData::Protobuf");
         }
@@ -861,15 +890,19 @@ mod tests {
         )
         .unwrap();
         if let CellData::Bincode(bincode_block) = deserialized {
-            let mut block = block;
-            if let Some(meta) = &mut block.transactions[0].meta {
+            let mut block = expected_block;
+            {
+                let mut meta = &mut block.transactions[0].meta;
                 meta.inner_instructions = None; // Legacy bincode implementation does not support inner_instructions
                 meta.log_messages = None; // Legacy bincode implementation does not support log_messages
                 meta.pre_token_balances = None; // Legacy bincode implementation does not support token balances
                 meta.post_token_balances = None; // Legacy bincode implementation does not support token balances
                 meta.rewards = None; // Legacy bincode implementation does not support rewards
             }
-            assert_eq!(block, bincode_block.into());
+            assert_eq!(
+                ConfirmedBlockWithOptionalMetadata::from(block),
+                ConfirmedBlockWithOptionalMetadata::from(bincode_block)
+            );
         } else {
             panic!("deserialization should produce CellData::Bincode");
         }
